# RCmodel

[![PyPI version](https://badge.fury.io/py/rcmodel.svg)](https://badge.fury.io/py/rcmodel)

RCmodel is a package which allows automatic creation of a simple Resistor Capacitor Model (3R2C) for  building thermal simulation.


## Installation

Install using pip:

`pip install rcmodel`

## Installation of latest development version

Install from GitHub:

`pip install git+https://github.com/BFourcin/rcmodel`